---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: ''
assignees: zainhoda

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Code to reproduce the behavior:


**Screenshots**
If applicable, add screenshots to help explain your problem.

**Details about your environment **
- Python version
- requirements.txt
- Anything else relevant

**Additional context**
Add any other context about the problem here.
